<?php
add_filter( 'ot_show_pages', '__return_false' );
add_filter( 'ot_show_new_layout', '__return_false' );

function qcld_express_remove_ot_menu () {
    remove_submenu_page( 'themes.php', 'ot-theme-options' );
}
add_action( 'admin_init', 'qcld_express_remove_ot_menu' );

add_filter( 'ot_header_version_text', 'qcld_express_developer_text' );

function qcld_express_developer_text(){
    $text = 'Developed by <a href="http://www.quantumcloud.com" target="_blank">Web Design Company - QuantumCloud</a> <a href="https://www.quantumcloud.com/products/express-shop/" style="font-weight: bold; color: #FCB214;"> Upgrade to Pro </a>';

    return $text;
}

/**
 * Hook to register admin pages
 */
add_action( 'init', 'qcld_express_ot_settings_options' );

/**
 * Registers all the required admin pages.
 */

function qcld_express_ot_settings_options() {

    // Only execute in admin & if OT is installed
    if ( is_admin() && function_exists( 'ot_register_settings' ) ) {
        //getting woocommerce product categories
        $terms = get_terms( array(
            'taxonomy' => 'product_cat',
            'hide_empty' => false,
        ) );
        $categories=array();
        if(class_exists('WooCommerce')){
            foreach ($terms as $term){
                $categories[] =array(
                    'value'       => $term->term_id,
                    'label'       => __( $term->name, 'qcld_express_cat_'.$term->slug ),
                );
            }
        }
        // Register the pages
        ot_register_settings(
            array(
                array(
                    'id'              => 'qcld_express_options',
                    'pages'           => array(
                        array(
                            'id'              => 'qcld_express_page',
                            'parent_slug'     => 'express-shop',
                            'page_title'      => 'Express Shop Settings',
                            'menu_title'      => 'Settings',
                            'capability'      => 'edit_theme_options',
                            'menu_slug'       => 'qcld-express-options',
                            'icon_url'        => null,
                            'position'        => null,
                            'updated_message' => 'Express Shop Options Updated.',
                            'reset_message'   => 'Express Shop Options Reset.',
                            'button_text'     => 'Save Changes',
                            'show_buttons'    => true,
                            'screen_icon'     => 'options-general',
                            'contextual_help' => null,

                            'sections'        => array(
                                array(
                                    'id'          => 'qcld_express_general',
                                    'title'       => __( 'General Settings', 'theme-text-domain' ),
                                ),
                                array(
                                    'id'          => 'qcld_express_css',
                                    'title'       => __( 'Express Shop Styles(CSS)', 'theme-text-domain' )
                                ),
                                array(
                                    'id'          => 'help',
                                    'title'       => __( 'Help', 'theme-text-domain' )
                                )
                            ),
                            'settings'        => array(
                                array(
                                    'id'          => 'qcld_express_show_mode',
                                    'label'       => __('Express Shop Products Loading Style'),
                                    'desc'        => __('Products showing styles will enable your WooCommerce Products as you want as you set from below style.'),
                                    'std'         => 'more',
                                    'type'        => 'radio',
                                    'section'     => 'qcld_express_general',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'min_max_step'=> '',
                                    'class'       => '',
                                    'condition'   => '',
                                    'operator'    => 'and',
                                    'choices'     => array(
                                        array(
                                            'value'       => 'more',
                                            'label'       => __( 'Load More Products', 'qcld-express-load-more' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => 'scroll',
                                            'label'       => __( 'Infinite Scrolling', 'qcld-express-infite-scroll' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => 'all',
                                            'label'       => __( 'Show All Products', 'qcld-express-show-all' ),
                                            'src'         => ''
                                        )
                                    )
                                ),
                                array(
                                    'label'       => __('Set products per page for Infinite Scroll and Load More Products'),
                                    'id'          => 'qcld_express_product_per_page',
                                    'type'        => 'text',
                                    'desc'        => __('Products per page for "Infinite Scroll" and "Load More Products" will display as you set from below.'),
                                    'std'         => '15',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Exclude Categories to show products.'),
                                    'id'          => 'qcld_express_category',
                                    'type'        => 'checkbox',
                                    'desc'        => __('Choose categories which\'s products will not be showing .'),
                                    'std'         => '',
                                    'rows'        => '5',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general',
                                    'choices'     => $categories
                                ),
                                array(
                                    'label'       => __('Template Option'),
                                    'id'          => 'qcld_express_template',
                                    'type'        => 'select',
                                    'desc'        => __('Choose Template for product showcase.'),
                                    'std'         => 'basic',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general',
                                    'choices'     => array(
                                        array(
                                            'value'       => '',
                                            'label'       => __( '-- Choose Template --', 'qcld_express_template' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => 'basic',
                                            'label'       => __( 'Basic Template', 'qcld_express_basic' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => 'animation',
                                            'label'       => __( 'Animated Template', 'qcld_express_animation' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => 'slope',
                                            'label'       => __( 'Alternative Slope Angle', 'qcld_express_angle' ),
                                            'src'         => ''
                                        )
                                    )
                                ),
                                array(
                                    'label'       => __('Endable category filter'),
                                    'id'          => 'qcld_express_filter',
                                    'type'        => 'on-off',
                                    'desc'        => __('Enable CATEGORY will show the filtering option for the products by category.'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Enable SKU Column'),
                                    'id'          => 'qcld_express_sku',
                                    'type'        => 'on-off',
                                    'desc'        => __('Enable SKU button will show the sku column of the products.'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Enable Product Thumbnail column'),
                                    'id'          => 'qcld_express_thumbnail',
                                    'type'        => 'on-off',
                                    'desc'        => __('Enable Product Thumbnail button will show the images (thumbnail) column of the products.'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Enable Title column'),
                                    'id'          => 'qcld_express_title',
                                    'type'        => 'on-off',
                                    'desc'        => __('Enable Title button will show the Title column of the products.'),
                                    'std'         => 'on',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Enable Description Column'),
                                    'id'          => 'qcld_express_description',
                                    'type'        => 'on-off',
                                    'desc'        => __('Enable Description button will show the products description column.'),
                                    'std'         => 'on',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),

                                array(
                                    'label'       => __('Enable Product Price Column'),
                                    'id'          => 'qcld_express_price',
                                    'type'        => 'on-off',
                                    'desc'        => __('Enable Product Price button will show the price column of the products'),
                                    'std'         => 'on',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Enable Action Column'),
                                    'id'          => 'qcld_express_action',
                                    'type'        => 'on-off',
                                    'desc'        => __('Enable Action button will show the sku column to take Action such as Add to car OR Configure etc. '),
                                    'std'         => 'on',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Enable Availability Column'),
                                    'id'          => 'qcld_express_stock',
                                    'type'        => 'on-off',
                                    'desc'        => __('Enable Availability button will show the Availability(InStock Or Out of Stock) column of the products.'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Set Show Low Stock Alert Beside Availability'),
                                    'id'          => 'qcld_express_stock_alert',
                                    'type'        => 'text',
                                    'desc'        => __('Show Low Stock will show the Availability with low stock alert in the Availability column of the products.'),
                                    'std'         => '5',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => 'Express Shop Page Background Color Setting',
                                    'id'          => 'qcld_express_background',
                                    'type'        => 'colorpicker',
                                    'desc'        => __('Background Color will be Express Shop product displaying grid.'),
                                    'std'         => '#FFFFFF',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_css'
                                ),
                                array(
                                    'label'       => 'Alternative Row Background color Setting',
                                    'id'          => 'qcld_express_altern',
                                    'type'        => 'colorpicker',
                                    'desc'        => __('Alternative Row Background color will be implemented to grid of the products.'),
                                    'std'         => '#E2E2E2',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_css'
                                ),
                                array(
                                    'label'       => 'Custom CSS',
                                    'id'          => 'qcld_express_custom_style',
                                    'type'        => 'textarea-simple',
                                    'desc'        => __('Write your custom CSS here.'),
                                    'std'         => '',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_css'
                                ),
                                array(
                                    'label'       => __('Help'),
                                    'id'          => 'qcld_express_help',
                                    'type'        => 'Textblock',
                                    'desc'        => '<div>
							<h3>Expres Shop Shortcode Example</h3>
							<p>
								
								[qcld_express_shop]
								<br>
								<br>
								<!--<strong><u>Available Parameters:</u></strong>
								<br>-->
							</p>
							<!--<p>
								<strong>1. mode</strong>
								<br>
								Value for this option can be set as "one" or "all".
								Example: mode="one"
							</p>
							<p>
								<strong>2. column</strong>
								<br>
								Avaialble values: "1", "2", "3".
								Example: column=1
							</p>

							<p>
								<strong>6. list_id</strong>
								<br>
								Only applicable if you want to display a single list [not all]. You can provide specific list id here as a value. You can also get ready shortcode for a single list under "Manage List Items" menu.
								Example: list_id="404"
							</p>
							
							<p>
								<strong>9. upvote</strong>
								<br>
								Values: on or off. This options allows upvoting of your list items.
								<br>
								Example: upvote="on"
							</p>-->

						</div>',
                                    'std'         => '',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'help'
                                ),
                            )
                        )
                    )
                )
            )
        );

    }

}

?>