<?php
if( !function_exists('ot_register_settings') ){
    require_once 'inc/option-tree/ot-loader.php';
}

add_filter( 'ot_show_pages', '__return_false' );
add_filter( 'ot_show_new_layout', '__return_false' );

function qcld_express_remove_ot_menu () {
    remove_submenu_page( 'themes.php', 'ot-theme-options' );
}
add_action( 'admin_init', 'qcld_express_remove_ot_menu' );

add_filter( 'ot_header_version_text', 'qcld_express_developer_text' );

function qcld_express_developer_text(){
    $text = 'Developed by <a href="http://www.quantumcloud.com" target="_blank">Web Design Company - QuantumCloud</a> ';

    return $text;
}

/**
 * Hook to register admin pages
 */
add_action( 'init', 'qcld_express_ot_settings_options' );

/**
 * Registers all the required admin pages.
 */

function qcld_express_ot_settings_options() {

    // Only execute in admin & if OT is installed
    if ( is_admin() && function_exists( 'ot_register_settings' ) ) {
        //getting woocommerce product categories
        $terms = get_terms( array(
            'taxonomy' => 'product_cat',
            'hide_empty' => false,
        ) );
        $categories=array();
        if(class_exists('WooCommerce')){
            foreach ($terms as $term){
                $categories[] =array(
                    'value'       => $term->term_id,
                    'label'       => __( $term->name, 'qcld_express_cat_'.$term->slug ),
                );
            }
        }
        // Register the pages
        ot_register_settings(
            array(
                array(
                    'id'              => 'qcld_express_options',
                    'pages'           => array(
                        array(
                            'id'              => 'qcld_express_page',
                            'parent_slug'     => 'express-shop',
                            'page_title'      => 'Express Shop Pro Settings',
                            'menu_title'      => 'Settings ',
                            'capability'      => 'edit_theme_options',
                            'menu_slug'       => 'qcld-express-options',
                            'icon_url'        => null,
                            'position'        => 10,
                            'updated_message' => 'Express Shop Options Updated.',
                            'reset_message'   => 'Express Shop Options Reset.',
                            'button_text'     => 'Save Changes',
                            'show_buttons'    => true,
                            'screen_icon'     => 'options-general',
                            'contextual_help' => null,

                            'sections'        => array(
                                array(
                                    'id'          => 'qcld_express_general',
                                    'title'       => __( 'General Settings', 'theme-text-domain' ),
                                ),
                                array(
                                    'id'          => 'qcld_express_css',
                                    'title'       => __( 'Style Settings', 'theme-text-domain' )
                                ),
                                array(
                                    'id'          => 'qcld_express_language',
                                    'title'       => __( 'Language Settings', 'theme-text-domain' ),
                                ),
                                
                                array(
                                    'id'          => 'help',
                                    'title'       => __( 'Help', 'theme-text-domain' )
                                )
                            ),
                            'settings'        => array(
                                array(
                                    'id'          => 'qcld_express_show_mode',
                                    'label'       => __('Express Shop Products Loading Style'),
                                    'desc'        => __('Set how to display all your products'),
                                    'std'         => 'more',
                                    'type'        => 'radio',
                                    'section'     => 'qcld_express_general',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'min_max_step'=> '',
                                    'class'       => '',
                                    'condition'   => '',
                                    'operator'    => 'and',
                                    'choices'     => array(
                                        array(
                                            'value'       => 'more',
                                            'label'       => __( 'Load More Products', 'qcld-express-load-more' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => 'scroll',
                                            'label'       => __( 'Infinite Scrolling', 'qcld-express-infite-scroll' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => 'all',
                                            'label'       => __( 'Show All Products', 'qcld-express-show-all' ),
                                            'src'         => ''
                                        )
                                    )
                                ),
                                array(
                                    'label'       => __('Set products per page for Infinite Scroll and Load More Products'),
                                    'id'          => 'qcld_express_product_per_page',
                                    'type'        => 'text',
                                    'desc'        => __('Products per page for "Infinite Scroll" or "Load More Products" will display as you set above'),
                                    'std'         => '10',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Express Shop cart summary style'),
                                    'id'          => 'qcld_express_cart_mode',
                                    'desc'        => __('Quick cart (button) position'),
                                    'std'         => 'float',
                                    'type'        => 'radio',
                                    'section'     => 'qcld_express_general',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'min_max_step'=> '',
                                    'class'       => '',
                                    'condition'   => '',
                                    'operator'    => 'and',
                                    'choices'     => array(
                                        array(
                                            'value'       => 'top',
                                            'label'       => __( 'Top Cart Summary', 'qcld-express-cart-summary' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => 'leftfloat',
                                            'label'       => __( 'Show Floating Cart Icon on the Left', 'qcld-express-cart-summary' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => 'rightfloat',
                                            'label'       => __( 'Show Floating Cart Icon on the Right', 'qcld-express-cart-summary' ),
                                            'src'         => ''
                                        ),
                                    )
                                ),
                                array(
                                    'label'       => __('Exclude Categories to show products.'),
                                    'id'          => 'qcld_express_category',
                                    'type'        => 'checkbox',
                                    'desc'        => __('Select categories to execute from product display'),
                                    'std'         => '',
                                    'rows'        => '5',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general',
                                    'choices'     => $categories
                                ),
                                array(
                                    'label'       => __('Template Option'),
                                    'id'          => 'qcld_express_template',
                                    'type'        => 'select',
                                    'desc'        => __('Choose Template for product showcase.'),
                                    'std'         => 'basic',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general',
                                    'choices'     => array(
                                        array(
                                            'value'       => '',
                                            'label'       => __( '-- Choose Template --', 'qcld_express_template' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => 'basic',
                                            'label'       => __( 'Basic Template (01)','qcld_express_basic' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => 'animation',
                                            'label'       => __( 'Animated Template (02)', 'qcld_express_animation' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => 'gradient',
                                            'label'       => __( 'Linear Gradient Template (03)', 'qcld_express_animation' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => 'restaurent',
                                            'label'       => __( 'Restaurent Template (04)', 'qcld_express_restaurent' ),
                                            'src'         => ''
                                        ),
                                        array(
                                            'value'       => 'restaurent-2',
                                            'label'       => __( 'Restaurent Template 2 (05)', 'qcld_express_restaurent-2' ),
                                            'src'         => ''
                                        ),
                                    )
                                ),
                                array(
                                    'label'       => __('Show Opening and Closing Hours'),
                                    'id'          => 'qcld_express_openclose',
                                    'type'        => 'on-off',
                                    'desc'        => __('Enable Or Disable to show opening and closing hours at top'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Opening and Closing Hours (Set id) '),
                                    'id'          => 'qcld_express_openclose_id',
                                    'type'        => 'text',
                                    'desc'        => __('Create your <a href="'.get_admin_url().'edit.php?post_type=op-set" target="_blank">opening hours</a> and copy the Set ID from the right bar'),
                                    'std'         => '',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Set Minimum Price for Checkout Order'),
                                    'id'          => 'qcld_express_min_num_price',
                                    'type'        => 'text',
                                    'desc'        => __('Set minimum total in orders required for checkout'),
                                    'std'         => '20.00',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Enable category filter'),
                                    'id'          => 'qcld_express_filter',
                                    'type'        => 'on-off',
                                    'desc'        => __('It enabled, category names will show at top for quick filtering'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Fixed Position Category Filters'),
                                    'id'          => 'qcld_express_sticky',
                                    'type'        => 'on-off',
                                    'desc'        => __('Turn on for fixed position category filter buttons'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Enable SKU Column'),
                                    'id'          => 'qcld_express_sku',
                                    'type'        => 'on-off',
                                    'desc'        => __('Enable to show SKUs '),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Enable Product Thumbnail column'),
                                    'id'          => 'qcld_express_thumbnail',
                                    'type'        => 'on-off',
                                    'desc'        => __('Enable Product Thumbnail button will show the images (thumbnail) column of the products.'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Enable Title column'),
                                    'id'          => 'qcld_express_title',
                                    'type'        => 'on-off',
                                    'desc'        => __('Enable Title button will show the Title column of the products.'),
                                    'std'         => 'on',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Enable Description Column'),
                                    'id'          => 'qcld_express_description',
                                    'type'        => 'on-off',
                                    'desc'        => __('Enable to show product <b style="color:red">excerpts</b> as description'),
                                    'std'         => 'on',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),

                                array(
                                    'label'       => __('Enable Product Price Column'),
                                    'id'          => 'qcld_express_price',
                                    'type'        => 'on-off',
                                    'desc'        => __('Enable Product Price button will show the price column of the products'),
                                    'std'         => 'on',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Enable Action Column'),
                                    'id'          => 'qcld_express_action',
                                    'type'        => 'on-off',
                                    'desc'        => __('Enable to show Add to Cart action '),
                                    'std'         => 'on',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Enable Availability Column'),
                                    'id'          => 'qcld_express_stock',
                                    'type'        => 'on-off',
                                    'desc'        => __('Enable Availability button will show the Availability(InStock Or Out of Stock) column of the products.'),
                                    'std'         => 'off',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => __('Set Show Low Stock Alert Beside Availability'),
                                    'id'          => 'qcld_express_stock_alert',
                                    'type'        => 'text',
                                    'desc'        => __('Show Low Stock will show the Availability with low stock alert in the Availability column of the products.'),
                                    'std'         => '5',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_general'
                                ),
                                array(
                                    'label'       => 'Express Shop Page Background Color Setting',
                                    'id'          => 'qcld_express_background',
                                    'type'        => 'colorpicker',
                                    'desc'        => __('Background Color will be Express Shop product displaying grid.'),
                                    'std'         => '',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_css'
                                ),
                                array(
                                    'label'       => 'Alternative Row Background color Setting',
                                    'id'          => 'qcld_express_altern',
                                    'type'        => 'colorpicker',
                                    'desc'        => __('Alternative Row Background color will be implemented to grid of the products for some templates.'),
                                    'std'         => '',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_css'
                                ),
                                array(
                                    'label'       => 'Restaurent Template Right Top Image',
                                    'id'          => 'qcld_express_top_img',
                                    'type'        => 'upload',
                                    'desc'        => __('Restaurent Template Right Top Image'),
                                    'std'         => '',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_css'
                                ),
                                array(
                                    'label'       => 'Restaurent Template Left Bottom Image',
                                    'id'          => 'qcld_express_bottom_img',
                                    'type'        => 'upload',
                                    'desc'        => __('Restaurent Template Left Bottom Image'),
                                    'std'         => '',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_css'
                                ),
                                array(
                                    'label'       => 'Custom CSS',
                                    'id'          => 'qcld_express_custom_style',
                                    'type'        => 'textarea-simple',
                                    'desc'        => __('Write your custom CSS here.'),
                                    'std'         => '',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_css'
                                ),
                                array(
                                    'label'       => __('Help'),
                                    'id'          => 'qcld_express_help',
                                    'type'        => 'Textblock',
                                    'desc'        => '<div>
                            <h3>Paste the Following Express Shop Shortcode on Any Page</h3>
                            <p>
                                
                                [qcld_express_shop] or [qcld_express_shop style="01"] ( ex: style="template number")
                                <br>
                                <br>
                                <!--<strong><u>Available Parameters:</u></strong>
                                <br>-->
                            </p>
                            <!--<p>
                                <strong>1. mode</strong>
                                <br>
                                Value for this option can be set as "one" or "all".
                                Example: mode="one"
                            </p>
                            <p>
                                <strong>2. column</strong>
                                <br>
                                Avaialble values: "1", "2", "3".
                                Example: column=1
                            </p>

                            <p>
                                <strong>6. list_id</strong>
                                <br>
                                Only applicable if you want to display a single list [not all]. You can provide specific list id here as a value. You can also get ready shortcode for a single list under "Manage List Items" menu.
                                Example: list_id="404"
                            </p>
                            
                            <p>
                                <strong>9. upvote</strong>
                                <br>
                                Values: on or off. This options allows upvoting of your list items.
                                <br>
                                Example: upvote="on"
                            </p>-->

                        </div>',
                                    'std'         => '',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'help'
                                ),
                                array(
                                    'label'       => __('Open Close Hours'),
                                    'id'          => 'qcld_express_helps',
                                    'type'        => 'Textblock',
                                    'desc'        => '<div>
                            <h3>Show Opening and Closing Hours</h3>
                            <p>Enable Opening and Closing Hours from General Settings</p>
                            <h3>Set Id</h3>
                            <p>Opening and Closing Hours post id value insert Opening and Closing Hours (Set id) Field to General settings</p>
                        </div>',
                                    'std'         => '',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'help'
                                ),

                                // Express shop pro language all array
                                 array(
                                    'label'       => __('SKU'),
                                    'id'          => 'qcld_express_lang_sku',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for SKU'),
                                    'std'         => 'SKU',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                               
                                array(
                                    'label'       => __('Thumbnail'),
                                    'id'          => 'qcld_express_lang_thumbnail',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Thumbnail'),
                                    'std'         => 'Thumbnail',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                               
                                array(
                                    'label'       => __('Title'),
                                    'id'          => 'qcld_express_lang_title',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Title'),
                                    'std'         => 'Title',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                               
                                array(
                                    'label'       => __('Description'),
                                    'id'          => 'qcld_express_lang_desc',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Description'),
                                    'std'         => 'Description',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                               
                                array(
                                    'label'       => __('Availability'),
                                    'id'          => 'qcld_express_lang_availability',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Availability'),
                                    'std'         => 'Availability',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('Price'),
                                    'id'          => 'qcld_express_lang_price',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Price'),
                                    'std'         => 'Price',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                               
                                array(
                                    'label'       => __('Action'),
                                    'id'          => 'qcld_express_lang_action',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Action'),
                                    'std'         => 'Action',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                               
                               
                                array(
                                    'label'       => __('Search'),
                                    'id'          => 'qcld_express_lang_search',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Search'),
                                    'std'         => 'Search',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('Cart Summary'),
                                    'id'          => 'qcld_express_lang_cart_summary',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Cart Summary'),
                                    'std'         => 'Cart Summary',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('Edit on Cart'),
                                    'id'          => 'qcld_express_lang_edit_on_cart',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Edit on Cart'),
                                    'std'         => 'Edit on Cart',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('Checkout'),
                                    'id'          => 'qcld_express_lang_checkout',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Checkout'),
                                    'std'         => 'Checkout',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('No products in the cart'),
                                    'id'          => 'qcld_express_lang_no_products',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for No products in the cart'),
                                    'std'         => 'No products in the cart',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('Minimum Price Alert Header 1'),
                                    'id'          => 'qcld_express_lang_cart_minimum_alert_1',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Cart Summary'),
                                    'std'         => 'Minimum Price is required before checking out.',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('Minimum Price Alert Header 2'),
                                    'id'          => 'qcld_express_lang_cart_minimum_alert_2',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Cart Summary'),
                                    'std'         => 'Current Total Price in the cart',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                                array(
                                    'label'       => __('Out of Stock Alert'),
                                    'id'          => 'qcld_express_lang_alert_out_of_stock',
                                    'type'        => 'text',
                                    'desc'        => __('Change the language for Cart Summary'),
                                    'std'         => 'The Product is Currently Out of Stock.',
                                    'rows'        => '',
                                    'post_type'   => '',
                                    'taxonomy'    => '',
                                    'class'       => '',
                                    'section'     => 'qcld_express_language'
                                ),
                               

                            )
                        )
                    )
                )
            )
        );
    }
}