<?php
/**
 * Plugin Name: Express Shop
 * Plugin URI: https://wordpress.org/plugins/express-shop
 * Description: Express Shop is a WooCommerce addon to show all products in one page
 * Version: 1.5.0
 * Author: QuantumCloud
 * Author URI: https://www.quantumcloud.com/
 * Requires at least: 4.0
 * Tested up to: 4.9
 * License: GPL2
 */

if (!defined('ABSPATH')) exit; // Exit if accessed directly
define('QCLD_EXPRESS_PLUGIN_DIR_URL', plugin_dir_url(__FILE__));
define('QCLD_EXPRESS_ASSETS_URL', QCLD_EXPRESS_PLUGIN_DIR_URL . "assets");
define('QCLD_EXPRESS_IMG_URL', QCLD_EXPRESS_ASSETS_URL . "/images");
define('QCLD_EXPRESS_REQUIRED_WOOCOMMERCE_VERSION', 2.2);
//setting dir
define('QCLD_EXPRESS_FILE_DIR', dirname(__FILE__));

//Load dependencies.
require_once('option-tree/ot-loader.php');
require_once('qcld-express-framework.php');
require_once('qcld-express-assets.php');
require_once('qcld-express-shortcode.php');
require_once('qcld-express-ajax.php');

//checking the woocommerce Plugin is activated or not then express shop will work.
Class QCLD_Express_Shop
{

    private static $instance;

    public static function qcld_express_get_instance()
    {
        if (!self::$instance) {
            self::$instance = new self();
            self::$instance->qcld_express_init();
        }

    }


    public function qcld_express_init()
    {

        // Check if WooCommerce is active, and is required WooCommerce version.
        if (!class_exists('WooCommerce') || version_compare(get_option('woocommerce_db_version'), QCLD_EXPRESS_REQUIRED_WOOCOMMERCE_VERSION, '<')) {
            add_action('admin_notices', array($this, 'qcld_express_woocommerce_inactive_notice'));
            return;
        }
    }


    /**
     * Display Notifications on specific criteria.
     *
     * @since    2.14
     */
    public static function qcld_express_woocommerce_inactive_notice()
    {
        if (current_user_can('activate_plugins')) :
            if (!class_exists('WooCommerce')) :
                deactivate_plugins(plugin_basename(__FILE__));
                //wp_die('You need to activate WooCommerce first.');
                ?>
                <div id="message" class="error">
                    <p>
                        <?php
                        printf(
                            __('%sQCLD Express Shop for WooCommerce REQUIRES WooCommerce%s %sWooCommerce%s must be active for QCLD Express Shop to work. Please install & activate WooCommerce.', 'qcld_express_shop'),
                            '<strong>',
                            '</strong><br>',
                            '<a href="http://wordpress.org/extend/plugins/woocommerce/" target="_blank" >',
                            '</a>'
                        );
                        ?>
                    </p>
                </div>
                <?php
            elseif (version_compare(get_option('woocommerce_db_version'), QC_JARVIS_REQUIRED_WOOCOMMERCE_VERSION, '<')) :
                ?>
                <div id="message" class="error">
                    <p>
                        <?php
                        printf(
                            __('%sQCLD Express Shop for WooCommerce is inactive%s This version of QCLD Express Shop requires WooCommerce %s or newer. For more information about our WooCommerce version support %sclick here%s.', 'qcld_express_shop'),
                            '<strong>',
                            '</strong><br>',
                            QC_JARVIS_REQUIRED_WOOCOMMERCE_VERSION
                        );
                        ?>
                    </p>
                    <div style="clear:both;"></div>
                </div>
                <?php
            endif;
        endif;
    }
}


/**
 * Instantiate plugin.
 *
 */

if (!function_exists('qcld_express_shop_load')) {
    function qcld_express_shop_load(){

        global $qcld_express_shop;

        $qcld_express_shop = QCLD_Express_Shop::qcld_express_get_instance();
    }
}
add_action('plugins_loaded', 'qcld_express_shop_load');


// Add  menu 
function qcld_express_add_sublavel_menu(){

    include_once 'class-qcld-free-plugin-upgrade-notice.php';

    add_menu_page(
        'Express Shop',
        'Express Shop',
        'manage_options',
        'express-shop',
        'qcld_express_opening_closing_hours',
        'dashicons-cart',
        20
    );

    add_submenu_page('express-shop',
        __('Opening  Hours', 'opening-hour'),
        __('Opening  Hours', 'opening-hour'),
        'manage_options',
        'express-shop'
    );

}
add_action('admin_menu', 'qcld_express_add_sublavel_menu');

function qcld_express_opening_closing_hours(){

    ?>
    <style>
        .qcld_express_wrap { background: #fff; box-shadow: 0px 0px 25px -5px rgba(0,0,0,0.45); padding: 20px; border-radius: 10px; min-height: 450px }
        .qcld_express_wrap h2 { padding-left: 0; font-weight: bold;}
        .qcld_express_wrap p { padding-left: 0; font-size:16px; font-weight: 400; }
        .qcld_express_wrap p a{ text-decoration: none }
    </style>

        <div class="wrap">
            <div class="qcld_express_wrap">
                <h2>Express Shop</h2>
                <p>Opening Hours is a Pro Version Feature. Please <a href="https://www.quantumcloud.com/products/express-shop/" target="_blank"><span style="font-weight: bold; color: #FCB214">Upgrade to the Pro Version. </span> </a></p>

                <div id="qcld_express_content">                  
                  <!-- Promo Block 1 -->
                  <div style="margin-top: 20px;"> <div class="qc-promo-plugins" ><img src="<?php echo QCLD_EXPRESS_IMG_URL ?>/qc-logo-full.png" alt="QuantumCloud Logo"><br><br><hr><br><a href="http://www.quantumcloud.com" target="_blank" style="margin-left: 65px;">QuantumCloud</a></div> </div>
                </div>
            </div>
        </div>

        <?php


}




